require(vegan)

###Miya22
dat_Miya <- read.csv("000_Miya22citizen.csv", header = TRUE, row.names=1)
# データフレームを0と1からなるバイナリーデータに変換します
data_binary <- as.data.frame(lapply(dat_Miya, function(x) ifelse(x > 0, 1, 0)))
rownames(data_binary) <- rownames(dat_Miya)
# バイナリーデータをCSVファイルに保存します
write.csv(data_binary, "out_binary_Miya22.csv", row.names = TRUE)


####################################################
#### 1 ### direct: 群衆間の類似度の計算と図示を 1 つの関数 meta MDS で行う。
# https://jsnfri.fra.affrc.go.jp/gunshu/2nmds.html
#direct.mds <- metaMDS(data_binary, distance="jaccard")
#pdf("out_nMDS_direct.pdf")
#plot(direct.mds, type="t", display="sites")
#dev.off()

####################################################
#### 2 ### 2 steps: 距離行列を一度作成し、この距離行列から二次元のプロットを作成する方法。
# https://jsnfri.fra.affrc.go.jp/gunshu/2nmds.html
# Jaccard 距離は一般的には連続値データに対しても定義されるため、
# オプションで binary = TRUE を指定しないと意図しない値が出てしまいます。
# 三木 (2024) P189
jc.vegdist = vegdist(data_binary, method="jaccard", binary=T)
two_step.mds <- metaMDS(jc.vegdist, distance="jaccard", binary = TRUE)
pdf("out_nMDS_2step.pdf")
#plot(two_step.mds, type="t", display="sites")
ordiplot(two_step.mds, type = "n")
points(two_step.mds, display = "sites", pch = 1, cex = 1.5)
text(two_step.mds, display = "sites", cex = 1, adj=c(0.5,-1.0), labels = rownames(data_binary))
dev.off()

####################################################
#### 3 ### hclust
#Copilot
#各クラスタリングメソッドの概要を以下に示します：
# "complete": Complete Linkage (完全連結法): クラスター間の最大距離を基準にクラスタリングを行います。最も遠い点同士の距離を考慮するため、クラスターが均一に分割される傾向があります。
# "average": Average Linkage (平均連結法)、UPGMAの 1 種: クラスター間の平均距離を基準にクラスタリングを行います。全ての点のペアの平均距離を考慮するため、バランスの取れたクラスタリングが得られます。
# "single": Single Linkage (単一連結法): クラスター間の最小距離を基準にクラスタリングを行います。最も近い点同士の距離を考慮するため、細長いクラスターが生成されることがあります。
# "ward.D": Ward's Method (ウォード法): クラスター内の分散の増加を最小化するようにクラスタリングを行います。結果として、均一でコンパクトなクラスターが得られます。
# "ward.D2": Ward.D2: Ward's Method の改良版で、異なる距離計算を使用します。より安定したクラスタリング結果が得られることがあります。
# "mcquitty": #McQuitty's Method (マクウィティ法): クラスター間の距離を加重平均で計算する方法です。比較的シンプルなアルゴリズムです。
# "median": Median Method (中央値法): クラスター間の距離を中央値で計算する方法です。外れ値の影響を受けにくい特徴があります。
# "centroid": Centroid Method (重心法): クラスターの重心間の距離を基準にクラスタリングを行います。クラスターの中心点を考慮するため、バランスの取れたクラスタリングが得られます。

#hc <- hclust(jc.vegdist, method = "ward.D2")
##hc <- hclust(dist_matrix, method = "average")
#pdf("out_hclust_wardD2.pdf")
#plot(hc, main = "ward.D2", xlab = "", sub = "", cex = 0.9)
#dev.off()
#
#hc <- hclust(jc.vegdist, method = "average")
##hc <- hclust(dist_matrix, method = "average")
#pdf("out_hclust_average.pdf")
#plot(hc, main = "average", xlab = "", sub = "", cex = 0.9)
#dev.off()


file_prefix = "out_hclust_"
file_extension = ".pdf"

# "complete": 
method_selected = "complete"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "average": 
method_selected = "average"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "single": 
method_selected = "single"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "ward.D": 
method_selected = "ward.D"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "ward.D2": 
method_selected = "ward.D2"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "ward.D2 as.dendrogram": 
method_selected = "ward.D2"
file_name <- paste(file_prefix, "ward.D2.as dendrogram", file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(as.dendrogram(hc), main = "ward.D2 as dendrogram()", xlab = "", sub = "", cex = 0.9)
#plot(hc, hang = -1, main = "ward.D2 hang-1", xlab = "", sub = "", cex = 0.9)
dev.off()

# "mcquitty": 
method_selected = "mcquitty"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "median": 
method_selected = "median"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()

# "centroid": 
method_selected = "centroid"
file_name <- paste(file_prefix, method_selected, file_extension, sep = "")
hc <- hclust(jc.vegdist, method = method_selected)
pdf(file_name)
plot(hc, main = method_selected, xlab = "", sub = "", cex = 0.9)
dev.off()





